swh-journal
===========

Persistent logger of changes to the archive, with publish-subscribe support.

See the
[documentation](https://docs.softwareheritage.org/devel/swh-journal/index.html#software-heritage-journal)
for more details.
